@@ -5,6 +5,14 @@
 #include "duktape.h"
 #include "duk_module_duktape.h"
 
+/* (v)snprintf() is missing before MSVC 2015.  Note that _(v)snprintf() does
+ * NOT NUL terminate on truncation, but that's OK here.
+ * http://stackoverflow.com/questions/2915672/snprintf-and-visual-studio-2010
+ */
+#if defined(_MSC_VER) && (_MSC_VER < 1900)
+#define snprintf _snprintf
+#endif
+
 #if 0  /* Enable manually */
 #define DUK__ASSERT(x) do { \
 		if (!(x)) { \
@@ -172,7 +180,7 @@ static void duk__resolve_module_id(duk_context *ctx, const char *req_id, const c
 	return;
 
  resolve_error:
-	duk_error(ctx, DUK_ERR_TYPE_ERROR, "cannot resolve module id: %s", (const char *) req_id);
+	(void) duk_type_error(ctx, "cannot resolve module id: %s", (const char *) req_id);
 }
 
 /* Stack indices for better readability. */
@@ -346,7 +354,7 @@ static duk_ret_t duk__require(duk_context *ctx) {
 	 * (Note capitalization: .filename matches Node.js while .fileName is
 	 * used elsewhere in Duktape.)
 	 */
-	duk_push_string(ctx, "})");
+	duk_push_string(ctx, "\n})");  /* Newline allows module last line to contain a // comment. */
 	duk_concat(ctx, 3);
 	if (!duk_get_prop_string(ctx, DUK__IDX_MODULE, "filename")) {
 		/* module.filename for .fileName, default to resolved ID if
@@ -424,7 +432,7 @@ static duk_ret_t duk__require(duk_context *ctx) {
  delete_rethrow:
 	duk_dup(ctx, DUK__IDX_RESOLVED_ID);
 	duk_del_prop(ctx, DUK__IDX_MODLOADED);  /* delete Duktape.modLoaded[resolved_id] */
-	duk_throw(ctx);  /* rethrow original error */
+	(void) duk_throw(ctx);  /* rethrow original error */
 	return 0;  /* not reachable */
 }
 
